@@ -1,6 +1,6 @@
 package Email::MIME::Kit::Assembler::Markdown;
 {
-  $Email::MIME::Kit::Assembler::Markdown::VERSION = '0.093071';
+  $Email::MIME::Kit::Assembler::Markdown::VERSION = '0.100000';
 }
 use Moose;
 with 'Email::MIME::Kit::Role::Assembler';
@@ -26,6 +26,12 @@ has text_wrapper => (
   isa => 'Str',
 );
 
+has munge_signature => (
+  is  => 'ro',
+  isa => 'Bool',
+  default => 0,
+);
+
 has renderer => (
   reader   => 'renderer',
   writer   => '_set_renderer',
@@ -90,16 +96,27 @@ sub _prep_header {
 
 sub assemble {
   my ($self, $stash) = @_;
-  
+
   my $markdown = ${ $self->kit->get_kit_entry( $self->path ) };
   if ($self->renderer) {
     my $output_ref = $self->renderer->render(\$markdown, $stash);
     $markdown = $$output_ref;
   }
 
+  my $plaintext = $markdown;
+
+  if ($self->munge_signature) {
+    my ($body, $sig) = split /^-- $/m, $markdown, 2;
+
+    if (defined $sig) {
+      $sig =~ s{^}{<br />}mg;
+      $markdown = "$body\n\n$sig";
+    }
+  }
+
   my %content = (
     html => Text::Markdown->new(tab_width => 2)->markdown($markdown),
-    text => $markdown,
+    text => $plaintext,
   );
 
   for my $type (keys %content) {
@@ -163,7 +180,7 @@ Email::MIME::Kit::Assembler::Markdown - build multipart/alternative messages fro
 
 =head1 VERSION
 
-version 0.093071
+version 0.100000
 
 =head1 SYNOPSIS
 
@@ -206,6 +223,11 @@ The C<text_wrapper> setting works exactly the same way, down to looking for an
 HTML-like comment containing the marker.  It wraps the Markdown content after
 it has been rendered by the kit's Renderer, if any.
 
+If given (and true), the C<munge_signature> option will perform some basic
+munging of a sigdash-prefixed signature in the source text, hardening line
+breaks.  The specific munging performed is not guaranteed to remain exactly
+stable.
+
 =for Pod::Coverage assemble BUILD
 
 =head1 AUTHOR
